@@ -7,7 +7,7 @@ use test_case::test_case;
 #[test_case(MarketType::LinearFuture, "BTC-USDT-210924")]
 #[test_case(MarketType::InverseSwap, "BTC-USD-SWAP")]
 #[test_case(MarketType::LinearSwap, "BTC-USDT-SWAP")]
-#[test_case(MarketType::EuropeanOption, "BTC-USD-210702-35000-C")]
+#[test_case(MarketType::EuropeanOption, "BTC-USD-210924-18000-P")]
 fn test_l2_snapshot(market_type: MarketType, symbol: &str) {
     let text = fetch_l2_snapshot("okex", market_type, symbol).unwrap();
     assert!(text.starts_with("{"));
